function [theta v] = segreg_sumofnorms(Phi,Y,lambda,w)
%segreg_sumofnorms solves 
%min_theta sum_t||Y_t-Phi_t*theta_t||^2 + lambda||(theta_t-theta_t+1)||.
%
%CALLING SEQUENCES:
% [theta v] = segreg_sumofnorms(Phi,Y,lambda,w)

% AUTHOR    Henrik Ohlsson <ohlsson@isy.liu.se>
% UPDATE    Dec 1 2009
%
% COPYRIGHT 2009 Henrik Ohlsson, Lennart Ljung and Stephen Boyd

[N n]=size(Phi);
if nargin < 4
    w = ones(N-1,1);
end

% building X
X=zeros(N,N*n);
for i=1:N
    X(i,:)=[zeros(1,n*(i-1)) Phi(i,:) zeros(1,n*N-n*(i-1)-n)];
end

% min_theta sum_t||Y_t-Phi_t*theta_t||^2+lambda sum_t||(theta_t-theta_t+1)||
cvx_begin
  variable theta(n,N)
  minimize( sum((Y-X*theta(:)).^2) ...
      + lambda*sum(norms(theta(:,2:end)-theta(:,1:end-1))*diag(w)))
cvx_end

v = norms(theta(:,2:end)-theta(:,1:end-1));